@@ -1,6 +1,13 @@
 package Parse::FixedRecord::Meta::Role::Class;
+BEGIN {
+  $Parse::FixedRecord::Meta::Role::Class::AUTHORITY = 'cpan:OSFAMERON';
+}
+{
+  $Parse::FixedRecord::Meta::Role::Class::VERSION = '0.06';
+}
 use Moose::Role;
 use Moose::Util::TypeConstraints;
+# ABSTRACT: metaclass trait for FixedRecord parsers
 
 use List::Util 'sum';
 
@@ -25,10 +32,20 @@ sub total_length {
 no Moose::Role;
 no Moose::Util::TypeConstraints;
 
+
+1;
+
+__END__
+=pod
+
 =head1 NAME
 
 Parse::FixedRecord::Meta::Role::Class - metaclass trait for FixedRecord parsers
 
+=head1 VERSION
+
+version 0.06
+
 =head1 DESCRIPTION
 
 Stores metadata about the parser. 
@@ -39,10 +56,16 @@ Stores metadata about the parser.
 
 Returns the total length of the string that will be parsed.
 
-=head1 AUTHOR and LICENSE
+=head1 AUTHOR
 
-    osfameron@cpan.org - see Parse::FixedRecord for full details and copyright
+osfameron <osfameron@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by osfameron.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
